unit ODLED;

{$R OdLedlit.res}

interface

uses WinProcs, Messages, Classes, Graphics, Controls, StdCtrls, ExtCtrls;

type
  TLedLittleColor = (lcBlack,lcDarkGray,lcRed,lcDarkRed,lcGreen,lcDarkGreen,
                 lcYellow,lcDarkYellow,lcBlue,lcDarkBlue,lcPurple,lcDarkPurple,
                 lcCyan,lcDarkCyan);

const
    LEDString : array[TLedLittleColor] of PChar = ('BLACKLED','DARKGRAYLED',
                'REDLED','DARKREDLED','GREENLED','DARKGREENLED', 'YELLOWLED',
                'DARKYELLOWLED','BLUELED','DARKBLUELED','PURPLELED',
                'DARKPURPLELED','CYANLED','DARKCYANLED');
type
  TODLedLittle = class(TImage)
  private
	{ Private declarations }
	Face: TBitmap;
	FLed,
    FClicLed: TLedLittleColor;
    Ftimer: TTimer;
    FBlink: Boolean;
    FInterval: Integer;
    FBkState: boolean;
    FOnBlink: TNotifyEvent;
    procedure SetBitmap(LED: TLedLittleColor);
    procedure DrawBitmap;
	procedure SetLed(NewLed: TLedLittleColor);
    procedure SetClicLed(NewLed: TLedLittleColor);
    procedure SetBlink(Onn :Boolean);
    procedure SetInterval(value: integer);
    procedure WMSize(var Msg: TWMSize); message WM_SIZE;
  protected
    procedure TimeHit(Sender: TObject);
  public
	{ Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Free;
    procedure Toggle;
    procedure MouseDown(Button: TMouseButton; Shift: TShiftState;
                X, Y: Integer); override;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState;
                X, Y: Integer); override;
  published
    property LedColor: TLedLittleColor read FLed write SetLed;
    property ClicLedColor: TLedLittleColor read FClicLed write SetClicLed;
    property Interval: Integer read Finterval write SetInterval;
    property Blink : Boolean read FBlink write SetBlink;
    property OnBlink: TNotifyEvent read FOnBlink write FOnBlink;
  end;

procedure Register;

implementation

Uses DsgnIntf, ODChoose;

{TODLedLittle}

constructor TODLedLittle.Create(AOwner: TComponent);
begin
    inherited Create(AOwner);
    ControlStyle := ControlStyle +[csOpaque];
    FLed := lcblack;
    Face := TBitmap.Create;
    Face.Handle := LoadBitmap(hInstance, 'BLACKLED');
    Self.Height := 16;
    Self.Width := 16;
    SetBitmap(lcBlack);
    FLed := lcBlack;
    FclicLed := lcDarkgray;
    Fblink := false;
    Finterval := 250;
    Ftimer := Nil;
    FbkState := False;
end;

destructor TODLedLittle.Free;
begin
    Face.Free;
    Face := nil;
    if assigned(Ftimer) then Ftimer.Free;
    inherited Free;
end;

procedure TODLedLittle.WMSize(var Msg: TWMSize);
begin
    inherited;
    DrawBitmap;
end;

procedure TODLedLittle.Toggle;
begin
    if fLed = lcdarkcyan then fled := lcblack else Inc(fled);
    SetBitmap(fled);
end;

procedure TODLedLittle.SetBitmap(LED: TLedLittleColor);
begin
    Face.Free;
    Face := nil;
    Face := TBitmap.Create;
    Face.Handle := LoadBitmap(hInstance, LedString[LED]);
    DrawBitmap;
end;

procedure TODLedLittle.DrawBitmap;
begin
    Picture.Bitmap.Width := Face.Width;
    Picture.Bitmap.Height := Face.Height;
    Picture.Bitmap.Canvas.CopyRect(Rect(0, 0, Face.Width, Face.Height),
                Face.Canvas, Rect(0, 0, Face.Width, Face.Height));
end;

procedure TODLedLittle.SetInterval(Value : Integer);
begin
    if Value = FInterval then Exit;

    if Assigned(Ftimer) then
      begin
        FTimer.Free;
        setbitmap(fled);
        FbkState := False;
      end;

    FTimer := Nil;

    if FBlink and (Value > 0) then
      begin
        FTimer := TTimer.Create(Self);
        FTimer.Interval := Value;
        FTimer.OnTimer := TimeHit;
      end;

    FInterval := Value;
end;

procedure TODLedLittle.SetBlink(Onn : boolean);
begin
    if Onn = FBlink then Exit;

    FBlink := Onn;
    if not Onn then
      begin
        if Assigned(Ftimer) then
          begin
            FTimer.Free;
            setbitmap(fled);
            FbkState := False;
          end;
        FTimer := Nil;
      end
    else if FInterval > 0 then
      begin
        FTimer := TTimer.Create(Self);
        FTimer.Interval := FInterval;
        FTimer.OnTimer := TimeHit;
      end;
end;

procedure TODLEdLittle.TimeHit(Sender : TObject);
begin
    Fbkstate := not fbkstate;
    if FbkState then
        SetBitMap(fclicled)
    else
        SetBitMap(fled);

    if Assigned(FOnBlink) then FOnBlink(Self);
end;

procedure TODLedLittle.SetLed(NewLed: TLedLittleColor);
begin
    FLed := NewLed;
    SetBitmap(fled);
end;

procedure TODLedLittle.SetClicLed(NewLed: TLedLittleColor);
begin
    FClicLed := NewLed;
end;

procedure TODLedLittle.MouseDown(Button: TMouseButton; Shift: TShiftState;
            X, Y: Integer);
begin
    if not Fblink then
        SetBitmap(FclicLed);
    inherited MouseDown(Button, Shift, X, Y);
end;


procedure TODLedLittle.MouseUp(Button: TMouseButton; Shift: TShiftState;
            X, Y: Integer);
begin
    inherited MouseUp(Button, Shift, X, Y);
    if not Fblink then
        SetBitmap(FLed);
end;

procedure Register;
begin
    RegisterComponents('Div4', [TODLedLittle]);
    RegisterPropertyEditor( TypeInfo( TLedLittleColor ), TODLedLittle,
                'LedColor', TLedLittleProperty );
    RegisterPropertyEditor( TypeInfo( TLedLittleColor ), TODLedLittle,
                'ClicLedColor', TLedLittleProperty );
end;

end.

